# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ScheduleObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'cron': 'str',
        'next_scheduled_time': 'datetime'
    }

    attribute_map = {
        'type': 'type',
        'cron': 'cron',
        'next_scheduled_time': 'next_scheduled_time'
    }

    def __init__(self, type=None, cron=None, next_scheduled_time=None, _configuration=None):  # noqa: E501
        """ScheduleObj - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._type = None
        self._cron = None
        self._next_scheduled_time = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if cron is not None:
            self.cron = cron
        if next_scheduled_time is not None:
            self.next_scheduled_time = next_scheduled_time

    @property
    def type(self):
        """Gets the type of this ScheduleObj.  # noqa: E501

        The schedule type. The valid values are 'Hourly', 'Daily', 'Weekly', 'Custom', 'Manual' and 'None'. 'Manual' means to trigger it right away and 'None' means to cancel the schedule.   # noqa: E501

        :return: The type of this ScheduleObj.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ScheduleObj.

        The schedule type. The valid values are 'Hourly', 'Daily', 'Weekly', 'Custom', 'Manual' and 'None'. 'Manual' means to trigger it right away and 'None' means to cancel the schedule.   # noqa: E501

        :param type: The type of this ScheduleObj.  # noqa: E501
        :type: str
        """
        allowed_values = ["Hourly", "Daily", "Weekly", "Custom", "Manual", "None"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def cron(self):
        """Gets the cron of this ScheduleObj.  # noqa: E501

        A cron expression, a time-based job scheduler.  # noqa: E501

        :return: The cron of this ScheduleObj.  # noqa: E501
        :rtype: str
        """
        return self._cron

    @cron.setter
    def cron(self, cron):
        """Sets the cron of this ScheduleObj.

        A cron expression, a time-based job scheduler.  # noqa: E501

        :param cron: The cron of this ScheduleObj.  # noqa: E501
        :type: str
        """

        self._cron = cron

    @property
    def next_scheduled_time(self):
        """Gets the next_scheduled_time of this ScheduleObj.  # noqa: E501

        The next time to schedule to run the job.  # noqa: E501

        :return: The next_scheduled_time of this ScheduleObj.  # noqa: E501
        :rtype: datetime
        """
        return self._next_scheduled_time

    @next_scheduled_time.setter
    def next_scheduled_time(self, next_scheduled_time):
        """Sets the next_scheduled_time of this ScheduleObj.

        The next time to schedule to run the job.  # noqa: E501

        :param next_scheduled_time: The next_scheduled_time of this ScheduleObj.  # noqa: E501
        :type: datetime
        """

        self._next_scheduled_time = next_scheduled_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScheduleObj, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduleObj):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScheduleObj):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class LdapApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def import_ldap_user(self, uid_list, **kwargs):  # noqa: E501
        """Import selected available ldap users.  # noqa: E501

        This endpoint adds the selected available ldap users to harbor based on related configuration parameters from the system. System will try to guess the user email address and realname, add to harbor user information. If have errors when import user, will return the list of importing failed uid and the failed reason.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_ldap_user(uid_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LdapImportUsers uid_list: The uid listed for importing. This list will check users validity of ldap service based on configuration from the system. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_ldap_user_with_http_info(uid_list, **kwargs)  # noqa: E501
        else:
            (data) = self.import_ldap_user_with_http_info(uid_list, **kwargs)  # noqa: E501
            return data

    def import_ldap_user_with_http_info(self, uid_list, **kwargs):  # noqa: E501
        """Import selected available ldap users.  # noqa: E501

        This endpoint adds the selected available ldap users to harbor based on related configuration parameters from the system. System will try to guess the user email address and realname, add to harbor user information. If have errors when import user, will return the list of importing failed uid and the failed reason.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_ldap_user_with_http_info(uid_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LdapImportUsers uid_list: The uid listed for importing. This list will check users validity of ldap service based on configuration from the system. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uid_list', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_ldap_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uid_list' is set
        if self.api_client.client_side_validation and ('uid_list' not in params or
                                                       params['uid_list'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `uid_list` when calling `import_ldap_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `import_ldap_user`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'uid_list' in params:
            body_params = params['uid_list']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/ldap/users/import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ping_ldap(self, **kwargs):  # noqa: E501
        """Ping available ldap service.  # noqa: E501

        This endpoint ping the available ldap service for test related configuration parameters.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ping_ldap(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param LdapConf ldapconf: ldap configuration. support input ldap service configuration. If it is a empty request, will load current configuration from the system.
        :return: LdapPingResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.ping_ldap_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.ping_ldap_with_http_info(**kwargs)  # noqa: E501
            return data

    def ping_ldap_with_http_info(self, **kwargs):  # noqa: E501
        """Ping available ldap service.  # noqa: E501

        This endpoint ping the available ldap service for test related configuration parameters.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ping_ldap_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param LdapConf ldapconf: ldap configuration. support input ldap service configuration. If it is a empty request, will load current configuration from the system.
        :return: LdapPingResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'ldapconf']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ping_ldap" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `ping_ldap`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ldapconf' in params:
            body_params = params['ldapconf']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/ldap/ping', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LdapPingResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_ldap_group(self, **kwargs):  # noqa: E501
        """Search available ldap groups.  # noqa: E501

        This endpoint searches the available ldap groups based on related configuration parameters. support to search by groupname or groupdn.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_ldap_group(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str groupname: Ldap group name
        :param str groupdn: The LDAP group DN
        :return: list[UserGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_ldap_group_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.search_ldap_group_with_http_info(**kwargs)  # noqa: E501
            return data

    def search_ldap_group_with_http_info(self, **kwargs):  # noqa: E501
        """Search available ldap groups.  # noqa: E501

        This endpoint searches the available ldap groups based on related configuration parameters. support to search by groupname or groupdn.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_ldap_group_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str groupname: Ldap group name
        :param str groupdn: The LDAP group DN
        :return: list[UserGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'groupname', 'groupdn']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_ldap_group" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `search_ldap_group`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'groupname' in params:
            query_params.append(('groupname', params['groupname']))  # noqa: E501
        if 'groupdn' in params:
            query_params.append(('groupdn', params['groupdn']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/ldap/groups/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserGroup]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_ldap_user(self, **kwargs):  # noqa: E501
        """Search available ldap users.  # noqa: E501

        This endpoint searches the available ldap users based on related configuration parameters. Support searched by input ladp configuration, load configuration from the system and specific filter.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_ldap_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str username: Registered user ID
        :return: list[LdapUser]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_ldap_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.search_ldap_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def search_ldap_user_with_http_info(self, **kwargs):  # noqa: E501
        """Search available ldap users.  # noqa: E501

        This endpoint searches the available ldap users based on related configuration parameters. Support searched by input ladp configuration, load configuration from the system and specific filter.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_ldap_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str username: Registered user ID
        :return: list[LdapUser]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'username']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_ldap_user" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `search_ldap_user`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/ldap/users/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LdapUser]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class PreheatPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'project_id': 'int',
        'provider_id': 'int',
        'provider_name': 'str',
        'filters': 'str',
        'trigger': 'str',
        'enabled': 'bool',
        'creation_time': 'datetime',
        'update_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'project_id': 'project_id',
        'provider_id': 'provider_id',
        'provider_name': 'provider_name',
        'filters': 'filters',
        'trigger': 'trigger',
        'enabled': 'enabled',
        'creation_time': 'creation_time',
        'update_time': 'update_time'
    }

    def __init__(self, id=None, name=None, description=None, project_id=None, provider_id=None, provider_name=None, filters=None, trigger=None, enabled=None, creation_time=None, update_time=None, _configuration=None):  # noqa: E501
        """PreheatPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._description = None
        self._project_id = None
        self._provider_id = None
        self._provider_name = None
        self._filters = None
        self._trigger = None
        self._enabled = None
        self._creation_time = None
        self._update_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if project_id is not None:
            self.project_id = project_id
        if provider_id is not None:
            self.provider_id = provider_id
        if provider_name is not None:
            self.provider_name = provider_name
        if filters is not None:
            self.filters = filters
        if trigger is not None:
            self.trigger = trigger
        if enabled is not None:
            self.enabled = enabled
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time

    @property
    def id(self):
        """Gets the id of this PreheatPolicy.  # noqa: E501

        The ID of preheat policy  # noqa: E501

        :return: The id of this PreheatPolicy.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PreheatPolicy.

        The ID of preheat policy  # noqa: E501

        :param id: The id of this PreheatPolicy.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this PreheatPolicy.  # noqa: E501

        The Name of preheat policy  # noqa: E501

        :return: The name of this PreheatPolicy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PreheatPolicy.

        The Name of preheat policy  # noqa: E501

        :param name: The name of this PreheatPolicy.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this PreheatPolicy.  # noqa: E501

        The Description of preheat policy  # noqa: E501

        :return: The description of this PreheatPolicy.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PreheatPolicy.

        The Description of preheat policy  # noqa: E501

        :param description: The description of this PreheatPolicy.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def project_id(self):
        """Gets the project_id of this PreheatPolicy.  # noqa: E501

        The ID of preheat policy project  # noqa: E501

        :return: The project_id of this PreheatPolicy.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this PreheatPolicy.

        The ID of preheat policy project  # noqa: E501

        :param project_id: The project_id of this PreheatPolicy.  # noqa: E501
        :type: int
        """

        self._project_id = project_id

    @property
    def provider_id(self):
        """Gets the provider_id of this PreheatPolicy.  # noqa: E501

        The ID of preheat policy provider  # noqa: E501

        :return: The provider_id of this PreheatPolicy.  # noqa: E501
        :rtype: int
        """
        return self._provider_id

    @provider_id.setter
    def provider_id(self, provider_id):
        """Sets the provider_id of this PreheatPolicy.

        The ID of preheat policy provider  # noqa: E501

        :param provider_id: The provider_id of this PreheatPolicy.  # noqa: E501
        :type: int
        """

        self._provider_id = provider_id

    @property
    def provider_name(self):
        """Gets the provider_name of this PreheatPolicy.  # noqa: E501

        The Name of preheat policy provider  # noqa: E501

        :return: The provider_name of this PreheatPolicy.  # noqa: E501
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this PreheatPolicy.

        The Name of preheat policy provider  # noqa: E501

        :param provider_name: The provider_name of this PreheatPolicy.  # noqa: E501
        :type: str
        """

        self._provider_name = provider_name

    @property
    def filters(self):
        """Gets the filters of this PreheatPolicy.  # noqa: E501

        The Filters of preheat policy  # noqa: E501

        :return: The filters of this PreheatPolicy.  # noqa: E501
        :rtype: str
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this PreheatPolicy.

        The Filters of preheat policy  # noqa: E501

        :param filters: The filters of this PreheatPolicy.  # noqa: E501
        :type: str
        """

        self._filters = filters

    @property
    def trigger(self):
        """Gets the trigger of this PreheatPolicy.  # noqa: E501

        The Trigger of preheat policy  # noqa: E501

        :return: The trigger of this PreheatPolicy.  # noqa: E501
        :rtype: str
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this PreheatPolicy.

        The Trigger of preheat policy  # noqa: E501

        :param trigger: The trigger of this PreheatPolicy.  # noqa: E501
        :type: str
        """

        self._trigger = trigger

    @property
    def enabled(self):
        """Gets the enabled of this PreheatPolicy.  # noqa: E501

        Whether the preheat policy enabled  # noqa: E501

        :return: The enabled of this PreheatPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this PreheatPolicy.

        Whether the preheat policy enabled  # noqa: E501

        :param enabled: The enabled of this PreheatPolicy.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def creation_time(self):
        """Gets the creation_time of this PreheatPolicy.  # noqa: E501

        The Create Time of preheat policy  # noqa: E501

        :return: The creation_time of this PreheatPolicy.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this PreheatPolicy.

        The Create Time of preheat policy  # noqa: E501

        :param creation_time: The creation_time of this PreheatPolicy.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this PreheatPolicy.  # noqa: E501

        The Update Time of preheat policy  # noqa: E501

        :return: The update_time of this PreheatPolicy.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this PreheatPolicy.

        The Update Time of preheat policy  # noqa: E501

        :param update_time: The update_time of this PreheatPolicy.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PreheatPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PreheatPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PreheatPolicy):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from harbor_client.api.ldap_api import LdapApi
from harbor_client.api.retention_api import RetentionApi
from harbor_client.api.system_cve_allowlist_api import SystemCVEAllowlistApi
from harbor_client.api.artifact_api import ArtifactApi
from harbor_client.api.auditlog_api import AuditlogApi
from harbor_client.api.configure_api import ConfigureApi
from harbor_client.api.gc_api import GcApi
from harbor_client.api.health_api import HealthApi
from harbor_client.api.icon_api import IconApi
from harbor_client.api.immutable_api import ImmutableApi
from harbor_client.api.jobservice_api import JobserviceApi
from harbor_client.api.label_api import LabelApi
from harbor_client.api.member_api import MemberApi
from harbor_client.api.oidc_api import OidcApi
from harbor_client.api.ping_api import PingApi
from harbor_client.api.preheat_api import PreheatApi
from harbor_client.api.project_api import ProjectApi
from harbor_client.api.project_metadata_api import ProjectMetadataApi
from harbor_client.api.purge_api import PurgeApi
from harbor_client.api.quota_api import QuotaApi
from harbor_client.api.registry_api import RegistryApi
from harbor_client.api.replication_api import ReplicationApi
from harbor_client.api.repository_api import RepositoryApi
from harbor_client.api.robot_api import RobotApi
from harbor_client.api.robotv1_api import Robotv1Api
from harbor_client.api.scan_api import ScanApi
from harbor_client.api.scan_all_api import ScanAllApi
from harbor_client.api.scan_data_export_api import ScanDataExportApi
from harbor_client.api.scanner_api import ScannerApi
from harbor_client.api.schedule_api import ScheduleApi
from harbor_client.api.search_api import SearchApi
from harbor_client.api.statistic_api import StatisticApi
from harbor_client.api.systeminfo_api import SysteminfoApi
from harbor_client.api.user_api import UserApi
from harbor_client.api.usergroup_api import UsergroupApi
from harbor_client.api.webhook_api import WebhookApi
from harbor_client.api.webhookjob_api import WebhookjobApi



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Metrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'task_count': 'int',
        'success_task_count': 'int',
        'error_task_count': 'int',
        'pending_task_count': 'int',
        'running_task_count': 'int',
        'scheduled_task_count': 'int',
        'stopped_task_count': 'int'
    }

    attribute_map = {
        'task_count': 'task_count',
        'success_task_count': 'success_task_count',
        'error_task_count': 'error_task_count',
        'pending_task_count': 'pending_task_count',
        'running_task_count': 'running_task_count',
        'scheduled_task_count': 'scheduled_task_count',
        'stopped_task_count': 'stopped_task_count'
    }

    def __init__(self, task_count=None, success_task_count=None, error_task_count=None, pending_task_count=None, running_task_count=None, scheduled_task_count=None, stopped_task_count=None, _configuration=None):  # noqa: E501
        """Metrics - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._task_count = None
        self._success_task_count = None
        self._error_task_count = None
        self._pending_task_count = None
        self._running_task_count = None
        self._scheduled_task_count = None
        self._stopped_task_count = None
        self.discriminator = None

        if task_count is not None:
            self.task_count = task_count
        if success_task_count is not None:
            self.success_task_count = success_task_count
        if error_task_count is not None:
            self.error_task_count = error_task_count
        if pending_task_count is not None:
            self.pending_task_count = pending_task_count
        if running_task_count is not None:
            self.running_task_count = running_task_count
        if scheduled_task_count is not None:
            self.scheduled_task_count = scheduled_task_count
        if stopped_task_count is not None:
            self.stopped_task_count = stopped_task_count

    @property
    def task_count(self):
        """Gets the task_count of this Metrics.  # noqa: E501

        The count of task  # noqa: E501

        :return: The task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._task_count

    @task_count.setter
    def task_count(self, task_count):
        """Sets the task_count of this Metrics.

        The count of task  # noqa: E501

        :param task_count: The task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._task_count = task_count

    @property
    def success_task_count(self):
        """Gets the success_task_count of this Metrics.  # noqa: E501

        The count of success task  # noqa: E501

        :return: The success_task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._success_task_count

    @success_task_count.setter
    def success_task_count(self, success_task_count):
        """Sets the success_task_count of this Metrics.

        The count of success task  # noqa: E501

        :param success_task_count: The success_task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._success_task_count = success_task_count

    @property
    def error_task_count(self):
        """Gets the error_task_count of this Metrics.  # noqa: E501

        The count of error task  # noqa: E501

        :return: The error_task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._error_task_count

    @error_task_count.setter
    def error_task_count(self, error_task_count):
        """Sets the error_task_count of this Metrics.

        The count of error task  # noqa: E501

        :param error_task_count: The error_task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._error_task_count = error_task_count

    @property
    def pending_task_count(self):
        """Gets the pending_task_count of this Metrics.  # noqa: E501

        The count of pending task  # noqa: E501

        :return: The pending_task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._pending_task_count

    @pending_task_count.setter
    def pending_task_count(self, pending_task_count):
        """Sets the pending_task_count of this Metrics.

        The count of pending task  # noqa: E501

        :param pending_task_count: The pending_task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._pending_task_count = pending_task_count

    @property
    def running_task_count(self):
        """Gets the running_task_count of this Metrics.  # noqa: E501

        The count of running task  # noqa: E501

        :return: The running_task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._running_task_count

    @running_task_count.setter
    def running_task_count(self, running_task_count):
        """Sets the running_task_count of this Metrics.

        The count of running task  # noqa: E501

        :param running_task_count: The running_task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._running_task_count = running_task_count

    @property
    def scheduled_task_count(self):
        """Gets the scheduled_task_count of this Metrics.  # noqa: E501

        The count of scheduled task  # noqa: E501

        :return: The scheduled_task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._scheduled_task_count

    @scheduled_task_count.setter
    def scheduled_task_count(self, scheduled_task_count):
        """Sets the scheduled_task_count of this Metrics.

        The count of scheduled task  # noqa: E501

        :param scheduled_task_count: The scheduled_task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._scheduled_task_count = scheduled_task_count

    @property
    def stopped_task_count(self):
        """Gets the stopped_task_count of this Metrics.  # noqa: E501

        The count of stopped task  # noqa: E501

        :return: The stopped_task_count of this Metrics.  # noqa: E501
        :rtype: int
        """
        return self._stopped_task_count

    @stopped_task_count.setter
    def stopped_task_count(self, stopped_task_count):
        """Sets the stopped_task_count of this Metrics.

        The count of stopped task  # noqa: E501

        :param stopped_task_count: The stopped_task_count of this Metrics.  # noqa: E501
        :type: int
        """

        self._stopped_task_count = stopped_task_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Metrics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Metrics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Metrics):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ImmutableRule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'priority': 'int',
        'disabled': 'bool',
        'action': 'str',
        'template': 'str',
        'params': 'dict(str, object)',
        'tag_selectors': 'list[ImmutableSelector]',
        'scope_selectors': 'dict(str, list[ImmutableSelector])'
    }

    attribute_map = {
        'id': 'id',
        'priority': 'priority',
        'disabled': 'disabled',
        'action': 'action',
        'template': 'template',
        'params': 'params',
        'tag_selectors': 'tag_selectors',
        'scope_selectors': 'scope_selectors'
    }

    def __init__(self, id=None, priority=None, disabled=None, action=None, template=None, params=None, tag_selectors=None, scope_selectors=None, _configuration=None):  # noqa: E501
        """ImmutableRule - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._priority = None
        self._disabled = None
        self._action = None
        self._template = None
        self._params = None
        self._tag_selectors = None
        self._scope_selectors = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if priority is not None:
            self.priority = priority
        if disabled is not None:
            self.disabled = disabled
        if action is not None:
            self.action = action
        if template is not None:
            self.template = template
        if params is not None:
            self.params = params
        if tag_selectors is not None:
            self.tag_selectors = tag_selectors
        if scope_selectors is not None:
            self.scope_selectors = scope_selectors

    @property
    def id(self):
        """Gets the id of this ImmutableRule.  # noqa: E501


        :return: The id of this ImmutableRule.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ImmutableRule.


        :param id: The id of this ImmutableRule.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def priority(self):
        """Gets the priority of this ImmutableRule.  # noqa: E501


        :return: The priority of this ImmutableRule.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this ImmutableRule.


        :param priority: The priority of this ImmutableRule.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def disabled(self):
        """Gets the disabled of this ImmutableRule.  # noqa: E501


        :return: The disabled of this ImmutableRule.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this ImmutableRule.


        :param disabled: The disabled of this ImmutableRule.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def action(self):
        """Gets the action of this ImmutableRule.  # noqa: E501


        :return: The action of this ImmutableRule.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this ImmutableRule.


        :param action: The action of this ImmutableRule.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def template(self):
        """Gets the template of this ImmutableRule.  # noqa: E501


        :return: The template of this ImmutableRule.  # noqa: E501
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this ImmutableRule.


        :param template: The template of this ImmutableRule.  # noqa: E501
        :type: str
        """

        self._template = template

    @property
    def params(self):
        """Gets the params of this ImmutableRule.  # noqa: E501


        :return: The params of this ImmutableRule.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this ImmutableRule.


        :param params: The params of this ImmutableRule.  # noqa: E501
        :type: dict(str, object)
        """

        self._params = params

    @property
    def tag_selectors(self):
        """Gets the tag_selectors of this ImmutableRule.  # noqa: E501


        :return: The tag_selectors of this ImmutableRule.  # noqa: E501
        :rtype: list[ImmutableSelector]
        """
        return self._tag_selectors

    @tag_selectors.setter
    def tag_selectors(self, tag_selectors):
        """Sets the tag_selectors of this ImmutableRule.


        :param tag_selectors: The tag_selectors of this ImmutableRule.  # noqa: E501
        :type: list[ImmutableSelector]
        """

        self._tag_selectors = tag_selectors

    @property
    def scope_selectors(self):
        """Gets the scope_selectors of this ImmutableRule.  # noqa: E501


        :return: The scope_selectors of this ImmutableRule.  # noqa: E501
        :rtype: dict(str, list[ImmutableSelector])
        """
        return self._scope_selectors

    @scope_selectors.setter
    def scope_selectors(self, scope_selectors):
        """Sets the scope_selectors of this ImmutableRule.


        :param scope_selectors: The scope_selectors of this ImmutableRule.  # noqa: E501
        :type: dict(str, list[ImmutableSelector])
        """

        self._scope_selectors = scope_selectors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImmutableRule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImmutableRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImmutableRule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class WebhookLastTrigger(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'policy_name': 'str',
        'event_type': 'str',
        'enabled': 'bool',
        'creation_time': 'datetime',
        'last_trigger_time': 'datetime'
    }

    attribute_map = {
        'policy_name': 'policy_name',
        'event_type': 'event_type',
        'enabled': 'enabled',
        'creation_time': 'creation_time',
        'last_trigger_time': 'last_trigger_time'
    }

    def __init__(self, policy_name=None, event_type=None, enabled=None, creation_time=None, last_trigger_time=None, _configuration=None):  # noqa: E501
        """WebhookLastTrigger - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._policy_name = None
        self._event_type = None
        self._enabled = None
        self._creation_time = None
        self._last_trigger_time = None
        self.discriminator = None

        if policy_name is not None:
            self.policy_name = policy_name
        if event_type is not None:
            self.event_type = event_type
        if enabled is not None:
            self.enabled = enabled
        if creation_time is not None:
            self.creation_time = creation_time
        if last_trigger_time is not None:
            self.last_trigger_time = last_trigger_time

    @property
    def policy_name(self):
        """Gets the policy_name of this WebhookLastTrigger.  # noqa: E501

        The webhook policy name.  # noqa: E501

        :return: The policy_name of this WebhookLastTrigger.  # noqa: E501
        :rtype: str
        """
        return self._policy_name

    @policy_name.setter
    def policy_name(self, policy_name):
        """Sets the policy_name of this WebhookLastTrigger.

        The webhook policy name.  # noqa: E501

        :param policy_name: The policy_name of this WebhookLastTrigger.  # noqa: E501
        :type: str
        """

        self._policy_name = policy_name

    @property
    def event_type(self):
        """Gets the event_type of this WebhookLastTrigger.  # noqa: E501

        The webhook event type.  # noqa: E501

        :return: The event_type of this WebhookLastTrigger.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this WebhookLastTrigger.

        The webhook event type.  # noqa: E501

        :param event_type: The event_type of this WebhookLastTrigger.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def enabled(self):
        """Gets the enabled of this WebhookLastTrigger.  # noqa: E501

        Whether or not the webhook policy enabled.  # noqa: E501

        :return: The enabled of this WebhookLastTrigger.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this WebhookLastTrigger.

        Whether or not the webhook policy enabled.  # noqa: E501

        :param enabled: The enabled of this WebhookLastTrigger.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def creation_time(self):
        """Gets the creation_time of this WebhookLastTrigger.  # noqa: E501

        The creation time of webhook policy.  # noqa: E501

        :return: The creation_time of this WebhookLastTrigger.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this WebhookLastTrigger.

        The creation time of webhook policy.  # noqa: E501

        :param creation_time: The creation_time of this WebhookLastTrigger.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def last_trigger_time(self):
        """Gets the last_trigger_time of this WebhookLastTrigger.  # noqa: E501

        The last trigger time of webhook policy.  # noqa: E501

        :return: The last_trigger_time of this WebhookLastTrigger.  # noqa: E501
        :rtype: datetime
        """
        return self._last_trigger_time

    @last_trigger_time.setter
    def last_trigger_time(self, last_trigger_time):
        """Sets the last_trigger_time of this WebhookLastTrigger.

        The last trigger time of webhook policy.  # noqa: E501

        :param last_trigger_time: The last_trigger_time of this WebhookLastTrigger.  # noqa: E501
        :type: datetime
        """

        self._last_trigger_time = last_trigger_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookLastTrigger, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookLastTrigger):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookLastTrigger):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Accessory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'artifact_id': 'int',
        'subject_artifact_id': 'int',
        'size': 'int',
        'digest': 'str',
        'type': 'str',
        'icon': 'str',
        'creation_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'artifact_id': 'artifact_id',
        'subject_artifact_id': 'subject_artifact_id',
        'size': 'size',
        'digest': 'digest',
        'type': 'type',
        'icon': 'icon',
        'creation_time': 'creation_time'
    }

    def __init__(self, id=None, artifact_id=None, subject_artifact_id=None, size=None, digest=None, type=None, icon=None, creation_time=None, _configuration=None):  # noqa: E501
        """Accessory - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._artifact_id = None
        self._subject_artifact_id = None
        self._size = None
        self._digest = None
        self._type = None
        self._icon = None
        self._creation_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if artifact_id is not None:
            self.artifact_id = artifact_id
        if subject_artifact_id is not None:
            self.subject_artifact_id = subject_artifact_id
        if size is not None:
            self.size = size
        if digest is not None:
            self.digest = digest
        if type is not None:
            self.type = type
        if icon is not None:
            self.icon = icon
        if creation_time is not None:
            self.creation_time = creation_time

    @property
    def id(self):
        """Gets the id of this Accessory.  # noqa: E501

        The ID of the accessory  # noqa: E501

        :return: The id of this Accessory.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Accessory.

        The ID of the accessory  # noqa: E501

        :param id: The id of this Accessory.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def artifact_id(self):
        """Gets the artifact_id of this Accessory.  # noqa: E501

        The artifact id of the accessory  # noqa: E501

        :return: The artifact_id of this Accessory.  # noqa: E501
        :rtype: int
        """
        return self._artifact_id

    @artifact_id.setter
    def artifact_id(self, artifact_id):
        """Sets the artifact_id of this Accessory.

        The artifact id of the accessory  # noqa: E501

        :param artifact_id: The artifact_id of this Accessory.  # noqa: E501
        :type: int
        """

        self._artifact_id = artifact_id

    @property
    def subject_artifact_id(self):
        """Gets the subject_artifact_id of this Accessory.  # noqa: E501

        The subject artifact id of the accessory  # noqa: E501

        :return: The subject_artifact_id of this Accessory.  # noqa: E501
        :rtype: int
        """
        return self._subject_artifact_id

    @subject_artifact_id.setter
    def subject_artifact_id(self, subject_artifact_id):
        """Sets the subject_artifact_id of this Accessory.

        The subject artifact id of the accessory  # noqa: E501

        :param subject_artifact_id: The subject_artifact_id of this Accessory.  # noqa: E501
        :type: int
        """

        self._subject_artifact_id = subject_artifact_id

    @property
    def size(self):
        """Gets the size of this Accessory.  # noqa: E501

        The artifact size of the accessory  # noqa: E501

        :return: The size of this Accessory.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Accessory.

        The artifact size of the accessory  # noqa: E501

        :param size: The size of this Accessory.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def digest(self):
        """Gets the digest of this Accessory.  # noqa: E501

        The artifact digest of the accessory  # noqa: E501

        :return: The digest of this Accessory.  # noqa: E501
        :rtype: str
        """
        return self._digest

    @digest.setter
    def digest(self, digest):
        """Sets the digest of this Accessory.

        The artifact digest of the accessory  # noqa: E501

        :param digest: The digest of this Accessory.  # noqa: E501
        :type: str
        """

        self._digest = digest

    @property
    def type(self):
        """Gets the type of this Accessory.  # noqa: E501

        The artifact size of the accessory  # noqa: E501

        :return: The type of this Accessory.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Accessory.

        The artifact size of the accessory  # noqa: E501

        :param type: The type of this Accessory.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def icon(self):
        """Gets the icon of this Accessory.  # noqa: E501

        The icon of the accessory  # noqa: E501

        :return: The icon of this Accessory.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this Accessory.

        The icon of the accessory  # noqa: E501

        :param icon: The icon of this Accessory.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def creation_time(self):
        """Gets the creation_time of this Accessory.  # noqa: E501

        The creation time of the accessory  # noqa: E501

        :return: The creation_time of this Accessory.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this Accessory.

        The creation time of the accessory  # noqa: E501

        :param creation_time: The creation_time of this Accessory.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Accessory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Accessory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Accessory):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class NativeReportSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'report_id': 'str',
        'scan_status': 'str',
        'severity': 'str',
        'duration': 'int',
        'summary': 'VulnerabilitySummary',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'complete_percent': 'int',
        'scanner': 'Scanner'
    }

    attribute_map = {
        'report_id': 'report_id',
        'scan_status': 'scan_status',
        'severity': 'severity',
        'duration': 'duration',
        'summary': 'summary',
        'start_time': 'start_time',
        'end_time': 'end_time',
        'complete_percent': 'complete_percent',
        'scanner': 'scanner'
    }

    def __init__(self, report_id=None, scan_status=None, severity=None, duration=None, summary=None, start_time=None, end_time=None, complete_percent=None, scanner=None, _configuration=None):  # noqa: E501
        """NativeReportSummary - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._report_id = None
        self._scan_status = None
        self._severity = None
        self._duration = None
        self._summary = None
        self._start_time = None
        self._end_time = None
        self._complete_percent = None
        self._scanner = None
        self.discriminator = None

        if report_id is not None:
            self.report_id = report_id
        if scan_status is not None:
            self.scan_status = scan_status
        if severity is not None:
            self.severity = severity
        if duration is not None:
            self.duration = duration
        if summary is not None:
            self.summary = summary
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if complete_percent is not None:
            self.complete_percent = complete_percent
        if scanner is not None:
            self.scanner = scanner

    @property
    def report_id(self):
        """Gets the report_id of this NativeReportSummary.  # noqa: E501

        id of the native scan report  # noqa: E501

        :return: The report_id of this NativeReportSummary.  # noqa: E501
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this NativeReportSummary.

        id of the native scan report  # noqa: E501

        :param report_id: The report_id of this NativeReportSummary.  # noqa: E501
        :type: str
        """

        self._report_id = report_id

    @property
    def scan_status(self):
        """Gets the scan_status of this NativeReportSummary.  # noqa: E501

        The status of the report generating process  # noqa: E501

        :return: The scan_status of this NativeReportSummary.  # noqa: E501
        :rtype: str
        """
        return self._scan_status

    @scan_status.setter
    def scan_status(self, scan_status):
        """Sets the scan_status of this NativeReportSummary.

        The status of the report generating process  # noqa: E501

        :param scan_status: The scan_status of this NativeReportSummary.  # noqa: E501
        :type: str
        """

        self._scan_status = scan_status

    @property
    def severity(self):
        """Gets the severity of this NativeReportSummary.  # noqa: E501

        The overall severity  # noqa: E501

        :return: The severity of this NativeReportSummary.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this NativeReportSummary.

        The overall severity  # noqa: E501

        :param severity: The severity of this NativeReportSummary.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def duration(self):
        """Gets the duration of this NativeReportSummary.  # noqa: E501

        The seconds spent for generating the report  # noqa: E501

        :return: The duration of this NativeReportSummary.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this NativeReportSummary.

        The seconds spent for generating the report  # noqa: E501

        :param duration: The duration of this NativeReportSummary.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def summary(self):
        """Gets the summary of this NativeReportSummary.  # noqa: E501


        :return: The summary of this NativeReportSummary.  # noqa: E501
        :rtype: VulnerabilitySummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this NativeReportSummary.


        :param summary: The summary of this NativeReportSummary.  # noqa: E501
        :type: VulnerabilitySummary
        """

        self._summary = summary

    @property
    def start_time(self):
        """Gets the start_time of this NativeReportSummary.  # noqa: E501

        The start time of the scan process that generating report  # noqa: E501

        :return: The start_time of this NativeReportSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this NativeReportSummary.

        The start time of the scan process that generating report  # noqa: E501

        :param start_time: The start_time of this NativeReportSummary.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this NativeReportSummary.  # noqa: E501

        The end time of the scan process that generating report  # noqa: E501

        :return: The end_time of this NativeReportSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this NativeReportSummary.

        The end time of the scan process that generating report  # noqa: E501

        :param end_time: The end_time of this NativeReportSummary.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def complete_percent(self):
        """Gets the complete_percent of this NativeReportSummary.  # noqa: E501

        The complete percent of the scanning which value is between 0 and 100  # noqa: E501

        :return: The complete_percent of this NativeReportSummary.  # noqa: E501
        :rtype: int
        """
        return self._complete_percent

    @complete_percent.setter
    def complete_percent(self, complete_percent):
        """Sets the complete_percent of this NativeReportSummary.

        The complete percent of the scanning which value is between 0 and 100  # noqa: E501

        :param complete_percent: The complete_percent of this NativeReportSummary.  # noqa: E501
        :type: int
        """

        self._complete_percent = complete_percent

    @property
    def scanner(self):
        """Gets the scanner of this NativeReportSummary.  # noqa: E501


        :return: The scanner of this NativeReportSummary.  # noqa: E501
        :rtype: Scanner
        """
        return self._scanner

    @scanner.setter
    def scanner(self, scanner):
        """Sets the scanner of this NativeReportSummary.


        :param scanner: The scanner of this NativeReportSummary.  # noqa: E501
        :type: Scanner
        """

        self._scanner = scanner

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NativeReportSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NativeReportSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NativeReportSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ReplicationTask(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'execution_id': 'int',
        'status': 'str',
        'job_id': 'str',
        'operation': 'str',
        'resource_type': 'str',
        'src_resource': 'str',
        'dst_resource': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'execution_id': 'execution_id',
        'status': 'status',
        'job_id': 'job_id',
        'operation': 'operation',
        'resource_type': 'resource_type',
        'src_resource': 'src_resource',
        'dst_resource': 'dst_resource',
        'start_time': 'start_time',
        'end_time': 'end_time'
    }

    def __init__(self, id=None, execution_id=None, status=None, job_id=None, operation=None, resource_type=None, src_resource=None, dst_resource=None, start_time=None, end_time=None, _configuration=None):  # noqa: E501
        """ReplicationTask - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._execution_id = None
        self._status = None
        self._job_id = None
        self._operation = None
        self._resource_type = None
        self._src_resource = None
        self._dst_resource = None
        self._start_time = None
        self._end_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if execution_id is not None:
            self.execution_id = execution_id
        if status is not None:
            self.status = status
        if job_id is not None:
            self.job_id = job_id
        if operation is not None:
            self.operation = operation
        if resource_type is not None:
            self.resource_type = resource_type
        if src_resource is not None:
            self.src_resource = src_resource
        if dst_resource is not None:
            self.dst_resource = dst_resource
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time

    @property
    def id(self):
        """Gets the id of this ReplicationTask.  # noqa: E501

        The ID of the task  # noqa: E501

        :return: The id of this ReplicationTask.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReplicationTask.

        The ID of the task  # noqa: E501

        :param id: The id of this ReplicationTask.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def execution_id(self):
        """Gets the execution_id of this ReplicationTask.  # noqa: E501

        The ID of the execution that the task belongs to  # noqa: E501

        :return: The execution_id of this ReplicationTask.  # noqa: E501
        :rtype: int
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this ReplicationTask.

        The ID of the execution that the task belongs to  # noqa: E501

        :param execution_id: The execution_id of this ReplicationTask.  # noqa: E501
        :type: int
        """

        self._execution_id = execution_id

    @property
    def status(self):
        """Gets the status of this ReplicationTask.  # noqa: E501

        The status of the task  # noqa: E501

        :return: The status of this ReplicationTask.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ReplicationTask.

        The status of the task  # noqa: E501

        :param status: The status of this ReplicationTask.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def job_id(self):
        """Gets the job_id of this ReplicationTask.  # noqa: E501

        The ID of the underlying job that the task related to  # noqa: E501

        :return: The job_id of this ReplicationTask.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ReplicationTask.

        The ID of the underlying job that the task related to  # noqa: E501

        :param job_id: The job_id of this ReplicationTask.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def operation(self):
        """Gets the operation of this ReplicationTask.  # noqa: E501

        The operation of the task  # noqa: E501

        :return: The operation of this ReplicationTask.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this ReplicationTask.

        The operation of the task  # noqa: E501

        :param operation: The operation of this ReplicationTask.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def resource_type(self):
        """Gets the resource_type of this ReplicationTask.  # noqa: E501

        The type of the resource that the task operates  # noqa: E501

        :return: The resource_type of this ReplicationTask.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ReplicationTask.

        The type of the resource that the task operates  # noqa: E501

        :param resource_type: The resource_type of this ReplicationTask.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def src_resource(self):
        """Gets the src_resource of this ReplicationTask.  # noqa: E501

        The source resource that the task operates  # noqa: E501

        :return: The src_resource of this ReplicationTask.  # noqa: E501
        :rtype: str
        """
        return self._src_resource

    @src_resource.setter
    def src_resource(self, src_resource):
        """Sets the src_resource of this ReplicationTask.

        The source resource that the task operates  # noqa: E501

        :param src_resource: The src_resource of this ReplicationTask.  # noqa: E501
        :type: str
        """

        self._src_resource = src_resource

    @property
    def dst_resource(self):
        """Gets the dst_resource of this ReplicationTask.  # noqa: E501

        The destination resource that the task operates  # noqa: E501

        :return: The dst_resource of this ReplicationTask.  # noqa: E501
        :rtype: str
        """
        return self._dst_resource

    @dst_resource.setter
    def dst_resource(self, dst_resource):
        """Sets the dst_resource of this ReplicationTask.

        The destination resource that the task operates  # noqa: E501

        :param dst_resource: The dst_resource of this ReplicationTask.  # noqa: E501
        :type: str
        """

        self._dst_resource = dst_resource

    @property
    def start_time(self):
        """Gets the start_time of this ReplicationTask.  # noqa: E501

        The start time of the task  # noqa: E501

        :return: The start_time of this ReplicationTask.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ReplicationTask.

        The start time of the task  # noqa: E501

        :param start_time: The start_time of this ReplicationTask.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ReplicationTask.  # noqa: E501

        The end time of the task  # noqa: E501

        :return: The end_time of this ReplicationTask.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ReplicationTask.

        The end time of the task  # noqa: E501

        :param end_time: The end_time of this ReplicationTask.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReplicationTask, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReplicationTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReplicationTask):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Schedule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'status': 'str',
        'creation_time': 'datetime',
        'update_time': 'datetime',
        'schedule': 'ScheduleObj',
        'parameters': 'dict(str, object)'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'creation_time': 'creation_time',
        'update_time': 'update_time',
        'schedule': 'schedule',
        'parameters': 'parameters'
    }

    def __init__(self, id=None, status=None, creation_time=None, update_time=None, schedule=None, parameters=None, _configuration=None):  # noqa: E501
        """Schedule - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._status = None
        self._creation_time = None
        self._update_time = None
        self._schedule = None
        self._parameters = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time
        if schedule is not None:
            self.schedule = schedule
        if parameters is not None:
            self.parameters = parameters

    @property
    def id(self):
        """Gets the id of this Schedule.  # noqa: E501

        The id of the schedule.  # noqa: E501

        :return: The id of this Schedule.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Schedule.

        The id of the schedule.  # noqa: E501

        :param id: The id of this Schedule.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this Schedule.  # noqa: E501

        The status of the schedule.  # noqa: E501

        :return: The status of this Schedule.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Schedule.

        The status of the schedule.  # noqa: E501

        :param status: The status of this Schedule.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def creation_time(self):
        """Gets the creation_time of this Schedule.  # noqa: E501

        the creation time of the schedule.  # noqa: E501

        :return: The creation_time of this Schedule.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this Schedule.

        the creation time of the schedule.  # noqa: E501

        :param creation_time: The creation_time of this Schedule.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this Schedule.  # noqa: E501

        the update time of the schedule.  # noqa: E501

        :return: The update_time of this Schedule.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Schedule.

        the update time of the schedule.  # noqa: E501

        :param update_time: The update_time of this Schedule.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    @property
    def schedule(self):
        """Gets the schedule of this Schedule.  # noqa: E501


        :return: The schedule of this Schedule.  # noqa: E501
        :rtype: ScheduleObj
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this Schedule.


        :param schedule: The schedule of this Schedule.  # noqa: E501
        :type: ScheduleObj
        """

        self._schedule = schedule

    @property
    def parameters(self):
        """Gets the parameters of this Schedule.  # noqa: E501

        The parameters of schedule job  # noqa: E501

        :return: The parameters of this Schedule.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Schedule.

        The parameters of schedule job  # noqa: E501

        :param parameters: The parameters of this Schedule.  # noqa: E501
        :type: dict(str, object)
        """

        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Schedule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Schedule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Schedule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class AuditLog(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'username': 'str',
        'resource': 'str',
        'resource_type': 'str',
        'operation': 'str',
        'op_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'username': 'username',
        'resource': 'resource',
        'resource_type': 'resource_type',
        'operation': 'operation',
        'op_time': 'op_time'
    }

    def __init__(self, id=None, username=None, resource=None, resource_type=None, operation=None, op_time=None, _configuration=None):  # noqa: E501
        """AuditLog - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._username = None
        self._resource = None
        self._resource_type = None
        self._operation = None
        self._op_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if username is not None:
            self.username = username
        if resource is not None:
            self.resource = resource
        if resource_type is not None:
            self.resource_type = resource_type
        if operation is not None:
            self.operation = operation
        if op_time is not None:
            self.op_time = op_time

    @property
    def id(self):
        """Gets the id of this AuditLog.  # noqa: E501

        The ID of the audit log entry.  # noqa: E501

        :return: The id of this AuditLog.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AuditLog.

        The ID of the audit log entry.  # noqa: E501

        :param id: The id of this AuditLog.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def username(self):
        """Gets the username of this AuditLog.  # noqa: E501

        Username of the user in this log entry.  # noqa: E501

        :return: The username of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AuditLog.

        Username of the user in this log entry.  # noqa: E501

        :param username: The username of this AuditLog.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def resource(self):
        """Gets the resource of this AuditLog.  # noqa: E501

        Name of the repository in this log entry.  # noqa: E501

        :return: The resource of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this AuditLog.

        Name of the repository in this log entry.  # noqa: E501

        :param resource: The resource of this AuditLog.  # noqa: E501
        :type: str
        """

        self._resource = resource

    @property
    def resource_type(self):
        """Gets the resource_type of this AuditLog.  # noqa: E501

        Tag of the repository in this log entry.  # noqa: E501

        :return: The resource_type of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AuditLog.

        Tag of the repository in this log entry.  # noqa: E501

        :param resource_type: The resource_type of this AuditLog.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def operation(self):
        """Gets the operation of this AuditLog.  # noqa: E501

        The operation against the repository in this log entry.  # noqa: E501

        :return: The operation of this AuditLog.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this AuditLog.

        The operation against the repository in this log entry.  # noqa: E501

        :param operation: The operation of this AuditLog.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def op_time(self):
        """Gets the op_time of this AuditLog.  # noqa: E501

        The time when this operation is triggered.  # noqa: E501

        :return: The op_time of this AuditLog.  # noqa: E501
        :rtype: datetime
        """
        return self._op_time

    @op_time.setter
    def op_time(self, op_time):
        """Sets the op_time of this AuditLog.

        The time when this operation is triggered.  # noqa: E501

        :param op_time: The op_time of this AuditLog.  # noqa: E501
        :type: datetime
        """

        self._op_time = op_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuditLog, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLog):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLog):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class UserApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_user(self, user_req, **kwargs):  # noqa: E501
        """Create a local user.  # noqa: E501

        This API can be used only when the authentication mode is for local DB.  When self registration is disabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user(user_req, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserCreationReq user_req: The new user (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_user_with_http_info(user_req, **kwargs)  # noqa: E501
        else:
            (data) = self.create_user_with_http_info(user_req, **kwargs)  # noqa: E501
            return data

    def create_user_with_http_info(self, user_req, **kwargs):  # noqa: E501
        """Create a local user.  # noqa: E501

        This API can be used only when the authentication mode is for local DB.  When self registration is disabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_with_http_info(user_req, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserCreationReq user_req: The new user (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_req', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_req' is set
        if self.api_client.client_side_validation and ('user_req' not in params or
                                                       params['user_req'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_req` when calling `create_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `create_user`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_req' in params:
            body_params = params['user_req']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user(self, user_id, **kwargs):  # noqa: E501
        """Mark a registered user as be removed.  # noqa: E501

        This endpoint let administrator of Harbor mark a registered user as removed.It actually won't be deleted from DB.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: User ID for marking as to be removed. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def delete_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Mark a registered user as be removed.  # noqa: E501

        This endpoint let administrator of Harbor mark a registered user as removed.It actually won't be deleted from DB.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: User ID for marking as to be removed. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `delete_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `delete_user`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_current_user_info(self, **kwargs):  # noqa: E501
        """Get current user info.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_user_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: UserResp
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_current_user_info_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_current_user_info_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_current_user_info_with_http_info(self, **kwargs):  # noqa: E501
        """Get current user info.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_user_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: UserResp
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_user_info" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_current_user_info`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResp',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_current_user_permissions(self, **kwargs):  # noqa: E501
        """Get current user permissions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_user_permissions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str scope: The scope for the permission
        :param bool relative: If true, the resources in the response are relative to the scope, eg for resource '/project/1/repository' if relative is 'true' then the resource in response will be 'repository'. 
        :return: list[Permission]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_current_user_permissions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_current_user_permissions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_current_user_permissions_with_http_info(self, **kwargs):  # noqa: E501
        """Get current user permissions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_user_permissions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str scope: The scope for the permission
        :param bool relative: If true, the resources in the response are relative to the scope, eg for resource '/project/1/repository' if relative is 'true' then the resource in response will be 'repository'. 
        :return: list[Permission]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'scope', 'relative']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_user_permissions" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_current_user_permissions`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scope' in params:
            query_params.append(('scope', params['scope']))  # noqa: E501
        if 'relative' in params:
            query_params.append(('relative', params['relative']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/current/permissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Permission]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user(self, user_id, **kwargs):  # noqa: E501
        """Get a user's profile.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: (required)
        :param str x_request_id: An unique ID for the request
        :return: UserResp
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Get a user's profile.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: (required)
        :param str x_request_id: An unique ID for the request
        :return: UserResp
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `get_user`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_user`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserResp',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_users(self, **kwargs):  # noqa: E501
        """List users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str q: Query string to query resources. Supported query patterns are \"exact match(k=v)\", \"fuzzy match(k=~v)\", \"range(k=[min~max])\", \"list with union releationship(k={v1 v2 v3})\" and \"list with intersetion relationship(k=(v1 v2 v3))\". The value of range and list can be string(enclosed by \" or '), integer or time(in format \"2020-04-09 02:36:00\"). All of these query patterns should be put in the query string \"q=xxx\" and splitted by \",\". e.g. q=k1=v1,k2=~v2,k3=[min~max]
        :param str sort: Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending orderr and field2 in descending order with \"sort=field1,-field2\"
        :param int page: The page number
        :param int page_size: The size of per page
        :return: list[UserResp]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_users_with_http_info(self, **kwargs):  # noqa: E501
        """List users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param str q: Query string to query resources. Supported query patterns are \"exact match(k=v)\", \"fuzzy match(k=~v)\", \"range(k=[min~max])\", \"list with union releationship(k={v1 v2 v3})\" and \"list with intersetion relationship(k=(v1 v2 v3))\". The value of range and list can be string(enclosed by \" or '), integer or time(in format \"2020-04-09 02:36:00\"). All of these query patterns should be put in the query string \"q=xxx\" and splitted by \",\". e.g. q=k1=v1,k2=~v2,k3=[min~max]
        :param str sort: Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending orderr and field2 in descending order with \"sort=field1,-field2\"
        :param int page: The page number
        :param int page_size: The size of per page
        :return: list[UserResp]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'q', 'sort', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_users" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `list_users`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('page_size' in params and params['page_size'] > 100):  # noqa: E501
            raise ValueError("Invalid value for parameter `page_size` when calling `list_users`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('page_size', params['page_size']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserResp]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_users(self, username, **kwargs):  # noqa: E501
        """Search users by username  # noqa: E501

        This endpoint is to search the users by username.  It's open for all authenticated requests.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_users(username, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: Username for filtering results. (required)
        :param str x_request_id: An unique ID for the request
        :param int page: The page number
        :param int page_size: The size of per page
        :return: list[UserSearchRespItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_users_with_http_info(username, **kwargs)  # noqa: E501
        else:
            (data) = self.search_users_with_http_info(username, **kwargs)  # noqa: E501
            return data

    def search_users_with_http_info(self, username, **kwargs):  # noqa: E501
        """Search users by username  # noqa: E501

        This endpoint is to search the users by username.  It's open for all authenticated requests.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_users_with_http_info(username, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str username: Username for filtering results. (required)
        :param str x_request_id: An unique ID for the request
        :param int page: The page number
        :param int page_size: The size of per page
        :return: list[UserSearchRespItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['username', 'x_request_id', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'username' is set
        if self.api_client.client_side_validation and ('username' not in params or
                                                       params['username'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `username` when calling `search_users`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `search_users`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('page_size' in params and params['page_size'] > 100):  # noqa: E501
            raise ValueError("Invalid value for parameter `page_size` when calling `search_users`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('page_size', params['page_size']))  # noqa: E501
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserSearchRespItem]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_cli_secret(self, user_id, secret, **kwargs):  # noqa: E501
        """Set CLI secret for a user.  # noqa: E501

        This endpoint let user generate a new CLI secret for himself.  This API only works when auth mode is set to 'OIDC'. Once this API returns with successful status, the old secret will be invalid, as there will be only one CLI secret for a user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_cli_secret(user_id, secret, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: User ID (required)
        :param OIDCCliSecretReq secret: (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_cli_secret_with_http_info(user_id, secret, **kwargs)  # noqa: E501
        else:
            (data) = self.set_cli_secret_with_http_info(user_id, secret, **kwargs)  # noqa: E501
            return data

    def set_cli_secret_with_http_info(self, user_id, secret, **kwargs):  # noqa: E501
        """Set CLI secret for a user.  # noqa: E501

        This endpoint let user generate a new CLI secret for himself.  This API only works when auth mode is set to 'OIDC'. Once this API returns with successful status, the old secret will be invalid, as there will be only one CLI secret for a user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_cli_secret_with_http_info(user_id, secret, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: User ID (required)
        :param OIDCCliSecretReq secret: (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'secret', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_cli_secret" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `set_cli_secret`")  # noqa: E501
        # verify the required parameter 'secret' is set
        if self.api_client.client_side_validation and ('secret' not in params or
                                                       params['secret'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `secret` when calling `set_cli_secret`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `set_cli_secret`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'secret' in params:
            body_params = params['secret']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_id}/cli_secret', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_user_sys_admin(self, user_id, sysadmin_flag, **kwargs):  # noqa: E501
        """Update a registered user to change to be an administrator of Harbor.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_user_sys_admin(user_id, sysadmin_flag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: (required)
        :param UserSysAdminFlag sysadmin_flag: Toggle a user to admin or not. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_user_sys_admin_with_http_info(user_id, sysadmin_flag, **kwargs)  # noqa: E501
        else:
            (data) = self.set_user_sys_admin_with_http_info(user_id, sysadmin_flag, **kwargs)  # noqa: E501
            return data

    def set_user_sys_admin_with_http_info(self, user_id, sysadmin_flag, **kwargs):  # noqa: E501
        """Update a registered user to change to be an administrator of Harbor.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_user_sys_admin_with_http_info(user_id, sysadmin_flag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: (required)
        :param UserSysAdminFlag sysadmin_flag: Toggle a user to admin or not. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'sysadmin_flag', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_user_sys_admin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `set_user_sys_admin`")  # noqa: E501
        # verify the required parameter 'sysadmin_flag' is set
        if self.api_client.client_side_validation and ('sysadmin_flag' not in params or
                                                       params['sysadmin_flag'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `sysadmin_flag` when calling `set_user_sys_admin`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `set_user_sys_admin`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'sysadmin_flag' in params:
            body_params = params['sysadmin_flag']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_id}/sysadmin', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_password(self, user_id, password, **kwargs):  # noqa: E501
        """Change the password on a user that already exists.  # noqa: E501

        This endpoint is for user to update password. Users with the admin role can change any user's password. Regular users can change only their own password.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_password(user_id, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: (required)
        :param PasswordReq password: Password to be updated, the attribute 'old_password' is optional when the API is called by the system administrator. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_password_with_http_info(user_id, password, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_password_with_http_info(user_id, password, **kwargs)  # noqa: E501
            return data

    def update_user_password_with_http_info(self, user_id, password, **kwargs):  # noqa: E501
        """Change the password on a user that already exists.  # noqa: E501

        This endpoint is for user to update password. Users with the admin role can change any user's password. Regular users can change only their own password.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_password_with_http_info(user_id, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: (required)
        :param PasswordReq password: Password to be updated, the attribute 'old_password' is optional when the API is called by the system administrator. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'password', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `update_user_password`")  # noqa: E501
        # verify the required parameter 'password' is set
        if self.api_client.client_side_validation and ('password' not in params or
                                                       params['password'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `password` when calling `update_user_password`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `update_user_password`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'password' in params:
            body_params = params['password']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_id}/password', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_profile(self, user_id, profile, **kwargs):  # noqa: E501
        """Update user's profile.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_profile(user_id, profile, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: Registered user ID (required)
        :param UserProfile profile: Only email, realname and comment can be modified. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_profile_with_http_info(user_id, profile, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_profile_with_http_info(user_id, profile, **kwargs)  # noqa: E501
            return data

    def update_user_profile_with_http_info(self, user_id, profile, **kwargs):  # noqa: E501
        """Update user's profile.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_profile_with_http_info(user_id, profile, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int user_id: Registered user ID (required)
        :param UserProfile profile: Only email, realname and comment can be modified. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'profile', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_profile" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in params or
                                                       params['user_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `update_user_profile`")  # noqa: E501
        # verify the required parameter 'profile' is set
        if self.api_client.client_side_validation and ('profile' not in params or
                                                       params['profile'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `profile` when calling `update_user_profile`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `update_user_profile`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['user_id'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'profile' in params:
            body_params = params['profile']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/users/{user_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
